microstructpy.meshing
=====================

.. automodule:: microstructpy.meshing

The meshing module contains two mesh classes,
the :class:`.PolyMesh` and the :class:`.TriMesh`.
The polygonal mesh contains a 2D or 3D tessellation of the microstructure
domain, while the triangular mesh is more suitable for direct numerical
simulation (finite element analysis).

.. only:: html

    **Module Contents**

.. toctree::

    polymesh
    trimesh